"""
vl_redis - Reserved Package Name

This package name has been reserved and is not yet available for use.
Please check back later or contact the maintainer for more information.
"""

__version__ = "0.0.1"
